%{!?kernel_version: %{expand: %%define kernel_version %(uname -r)}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | perl -pe 's/^.*-(.*?)$/$1/g')}}

# Definitions for symvers files.
%define vmw_symvers_dir etc/vmware-tools/symvers
%define bld_symvers_file Modules.symvers

Name:         vmware-tools-vmblock
BuildRequires: kernel-source kernel-syms gcc make perl
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vmblock kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.1.2.0
Release:      1.sles10
Source1:      vmblock-configModule.tar.gz
BuildRoot:    %{_tmppath}/%{name}-%{version}-build

Source0:      vmblock.tar
Source2:      vmblock-vmware-PLDP-spec

%define kernel_version %(uname -r|perl -pe 's/^(.*)-.*?$/$1/g')

%define vmware_use_symvers_file 1

# Lock down flavors to build to just the current flavor.
%{expand: %%define current_flavor %(uname -r|perl -pe 's/^.*-(.*)$/$1/g')}
%suse_kernel_module_package -s %{SOURCE2} -x %{current_flavor}

%prep
%setup -n vmblock-only

%build
for flavor in %flavors_to_build; do
  VMCI_SYMVERS_FILE=/%{vmw_symvers_dir}/vmci-9.0.3.0-%{kernel_version}-$flavor

  rm -rf ../$flavor ../vmblock.o
  make HEADER_DIR=/usr/src/linux-obj/%{_arch}/$flavor BUILD_DIR=/usr/src/linux-obj/%{_arch}/$flavor clean

  # For modules that depend on vmci, copy in the vmci symvers file
  # or die trying.
  # XXX: I can only handle dependency on one module's symvers file.
  if [ "vmblock" = "vsock" -o "vmblock" = "vmhgfs" ]; then
     if [ ! -e $VMCI_SYMVERS_FILE ]; then
        echo
        echo
        echo "
ERROR: Could not find $VMCI_SYMVERS_FILE.  This package relies on kernel symbols for the currently running kernel that are built from the vmware-tools-vmci source RPM package.  Please do the following:

- Rebuild the vmware-tools-vmci source RPM package.
- Install the resulting binary RPM from /usr/src/packages/RPMS/\$ARCH/.
- Rebuild this package again."
        echo
        echo
        exit 1
     fi
     cp -f $VMCI_SYMVERS_FILE ./%{bld_symvers_file}
  fi

  make HEADER_DIR=/usr/src/linux-obj/%{_arch}/$flavor BUILD_DIR=/usr/src/linux-obj/%{_arch}/$flavor
  mkdir ../$flavor
  cp ../vmblock.o ../$flavor

  # Take the symvers file with us as well.
  cp ./%{bld_symvers_file} ../$flavor/%{bld_symvers_file}
done

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
for flavor in %flavors_to_build; do
  vmblock_SYMVERS_FILE=%{vmw_symvers_dir}/vmblock-1.1.2.0-%{kernel_version}-$flavor
  # Install the module and symvers file.
  install -m 644 -D ../$flavor/vmblock.o $RPM_BUILD_ROOT/lib/modules/%{kernel_version}-$flavor/updates/vmblock.ko
  install -m 644 -D ../$flavor/%{bld_symvers_file} $RPM_BUILD_ROOT/$vmblock_SYMVERS_FILE
done
# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vmblock.  The vmblock module is used by vmware-user to block file access to files that are in the process of being copied from host to guest or guest to host (such as a drag and drop operation between a host and a guest).

%package common
Summary:      Contains the common files used by all the vmblock kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.10
Release:      1.sles10
Version:      8.6.10

%description common
 This package contains the common system configuration and scripts responsible for loading the vmblock kernel module.  The vmblock module is used by vmware-user to block file access to files that are in the process of being copied from host to guest or guest to host (such as a drag and drop operation between a host and a guest).

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vmblock ]; then
      /sbin/insserv -r vmblock >/dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vmblock/vmware-deconfig.pl --os=linux,sle,10 --kernel=%{kernel_version} --toDeconfigure=vmblock
   /usr/lib/vmware-tools/moduleScripts/vmblock/vmware-db.pl --os=linux,sle,10 --dbDelAnswer VMBLOCK_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vmblock/vmware-db.pl --os=linux,sle,10 --dbAddAnswer VMBLOCK_NAME,vmblock
/usr/lib/vmware-tools/moduleScripts/vmblock/vmware-config.pl --os=linux,sle,10 --kernel=%{kernel_version} --toConfigure=vmblock
if [ -e /etc/init.d/vmblock ]; then
   /sbin/insserv -f vmblock >/dev/null 2>&1
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vmblock ]; then
      /sbin/insserv -r vmblock >/dev/null 2>&1
   fi
   /usr/lib/vmware-tools/moduleScripts/vmblock/vmware-deconfig.pl --os=linux,sle,10 --kernel=%{kernel_version} --toDeconfigure=vmblock
   /usr/lib/vmware-tools/moduleScripts/vmblock/vmware-db.pl --os=linux,sle,10 --dbDelAnswer VMBLOCK_NAME
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vmblock/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vmblock/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vmblock/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vmblock/vmware-config.pl
/etc/init.d/vmblock
